@@ -1,7 +1,12 @@
+# Capture the original matplotlib rcParams
+import matplotlib as mpl
+_orig_rc_params = mpl.rcParams.copy()
+
+# Import seaborn objects
 from .rcmod import *
 from .utils import *
 from .palettes import *
-from .linearmodels import *
+from .regression import *
 from .categorical import *
 from .distributions import *
 from .timeseries import *
@@ -11,6 +16,6 @@ from .axisgrid import *
 from .widgets import *
 from .xkcd_rgb import xkcd_rgb
 from .crayons import crayons
-set()
+from . import cm
 
-__version__ = "0.7.0"
+__version__ = "0.8.1"
